Class: Aws::ComputeOptimizer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ComputeOptimizer::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-computeoptimizer/client.rb
Overview
An API client for ComputeOptimizer. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ComputeOptimizer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_recommendation_preferences(params = {}) ⇒ Struct
Deletes a recommendation preference, such as enhanced infrastructure metrics.
-
#describe_recommendation_export_jobs(params = {}) ⇒ Types::DescribeRecommendationExportJobsResponse
Describes recommendation export jobs created in the last seven days.
-
#export_auto_scaling_group_recommendations(params = {}) ⇒ Types::ExportAutoScalingGroupRecommendationsResponse
Exports optimization recommendations for Auto Scaling groups.
-
#export_ebs_volume_recommendations(params = {}) ⇒ Types::ExportEBSVolumeRecommendationsResponse
Exports optimization recommendations for Amazon EBS volumes.
-
#export_ec2_instance_recommendations(params = {}) ⇒ Types::ExportEC2InstanceRecommendationsResponse
Exports optimization recommendations for Amazon EC2 instances.
-
#export_ecs_service_recommendations(params = {}) ⇒ Types::ExportECSServiceRecommendationsResponse
Exports optimization recommendations for Amazon ECS services on Fargate.
-
#export_idle_recommendations(params = {}) ⇒ Types::ExportIdleRecommendationsResponse
Export optimization recommendations for your idle resources.
-
#export_lambda_function_recommendations(params = {}) ⇒ Types::ExportLambdaFunctionRecommendationsResponse
Exports optimization recommendations for Lambda functions.
-
#export_license_recommendations(params = {}) ⇒ Types::ExportLicenseRecommendationsResponse
Export optimization recommendations for your licenses.
-
#export_rds_database_recommendations(params = {}) ⇒ Types::ExportRDSDatabaseRecommendationsResponse
Export optimization recommendations for your Amazon Aurora and Amazon Relational Database Service (Amazon RDS) databases.
-
#get_auto_scaling_group_recommendations(params = {}) ⇒ Types::GetAutoScalingGroupRecommendationsResponse
Returns Auto Scaling group recommendations.
-
#get_ebs_volume_recommendations(params = {}) ⇒ Types::GetEBSVolumeRecommendationsResponse
Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
-
#get_ec2_instance_recommendations(params = {}) ⇒ Types::GetEC2InstanceRecommendationsResponse
Returns Amazon EC2 instance recommendations.
-
#get_ec2_recommendation_projected_metrics(params = {}) ⇒ Types::GetEC2RecommendationProjectedMetricsResponse
Returns the projected utilization metrics of Amazon EC2 instance recommendations.
-
#get_ecs_service_recommendation_projected_metrics(params = {}) ⇒ Types::GetECSServiceRecommendationProjectedMetricsResponse
Returns the projected metrics of Amazon ECS service recommendations.
-
#get_ecs_service_recommendations(params = {}) ⇒ Types::GetECSServiceRecommendationsResponse
Returns Amazon ECS service recommendations.
-
#get_effective_recommendation_preferences(params = {}) ⇒ Types::GetEffectiveRecommendationPreferencesResponse
Returns the recommendation preferences that are in effect for a given resource, such as enhanced infrastructure metrics.
-
#get_enrollment_status(params = {}) ⇒ Types::GetEnrollmentStatusResponse
Returns the enrollment (opt in) status of an account to the Compute Optimizer service.
-
#get_enrollment_statuses_for_organization(params = {}) ⇒ Types::GetEnrollmentStatusesForOrganizationResponse
Returns the Compute Optimizer enrollment (opt-in) status of organization member accounts, if your account is an organization management account.
-
#get_idle_recommendations(params = {}) ⇒ Types::GetIdleRecommendationsResponse
Returns idle resource recommendations.
-
#get_lambda_function_recommendations(params = {}) ⇒ Types::GetLambdaFunctionRecommendationsResponse
Returns Lambda function recommendations.
-
#get_license_recommendations(params = {}) ⇒ Types::GetLicenseRecommendationsResponse
Returns license recommendations for Amazon EC2 instances that run on a specific license.
-
#get_rds_database_recommendation_projected_metrics(params = {}) ⇒ Types::GetRDSDatabaseRecommendationProjectedMetricsResponse
Returns the projected metrics of Aurora and RDS database recommendations.
-
#get_rds_database_recommendations(params = {}) ⇒ Types::GetRDSDatabaseRecommendationsResponse
Returns Amazon Aurora and RDS database recommendations.
-
#get_recommendation_preferences(params = {}) ⇒ Types::GetRecommendationPreferencesResponse
Returns existing recommendation preferences, such as enhanced infrastructure metrics.
-
#get_recommendation_summaries(params = {}) ⇒ Types::GetRecommendationSummariesResponse
Returns the optimization findings for an account.
-
#put_recommendation_preferences(params = {}) ⇒ Struct
Creates a new recommendation preference or updates an existing recommendation preference, such as enhanced infrastructure metrics.
-
#update_enrollment_status(params = {}) ⇒ Types::UpdateEnrollmentStatusResponse
Updates the enrollment (opt in and opt out) status of an account to the Compute Optimizer service.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3585 3586 3587 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3585 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3588 3589 3590 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3588 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3558 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ComputeOptimizer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-computeoptimizer' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_recommendation_preferences(params = {}) ⇒ Struct
Deletes a recommendation preference, such as enhanced infrastructure metrics.
For more information, see [Activating enhanced infrastructure metrics] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
536 537 538 539 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 536 def delete_recommendation_preferences(params = {}, = {}) req = build_request(:delete_recommendation_preferences, params) req.send_request() end |
#describe_recommendation_export_jobs(params = {}) ⇒ Types::DescribeRecommendationExportJobsResponse
Describes recommendation export jobs created in the last seven days.
Use the ExportAutoScalingGroupRecommendations or ExportEC2InstanceRecommendations actions to request an export of your recommendations. Then use the DescribeRecommendationExportJobs action to view your export jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
610 611 612 613 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 610 def describe_recommendation_export_jobs(params = {}, = {}) req = build_request(:describe_recommendation_export_jobs, params) req.send_request() end |
#export_auto_scaling_group_recommendations(params = {}) ⇒ Types::ExportAutoScalingGroupRecommendationsResponse
Exports optimization recommendations for Auto Scaling groups.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one Auto Scaling group export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
748 749 750 751 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 748 def export_auto_scaling_group_recommendations(params = {}, = {}) req = build_request(:export_auto_scaling_group_recommendations, params) req.send_request() end |
#export_ebs_volume_recommendations(params = {}) ⇒ Types::ExportEBSVolumeRecommendationsResponse
Exports optimization recommendations for Amazon EBS volumes.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one Amazon EBS volume export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
879 880 881 882 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 879 def export_ebs_volume_recommendations(params = {}, = {}) req = build_request(:export_ebs_volume_recommendations, params) req.send_request() end |
#export_ec2_instance_recommendations(params = {}) ⇒ Types::ExportEC2InstanceRecommendationsResponse
Exports optimization recommendations for Amazon EC2 instances.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one Amazon EC2 instance export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1014 1015 1016 1017 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1014 def export_ec2_instance_recommendations(params = {}, = {}) req = build_request(:export_ec2_instance_recommendations, params) req.send_request() end |
#export_ecs_service_recommendations(params = {}) ⇒ Types::ExportECSServiceRecommendationsResponse
Exports optimization recommendations for Amazon ECS services on Fargate.
Recommendations are exported in a CSV file, and its metadata in a JSON file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can only have one Amazon ECS service export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1144 1145 1146 1147 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1144 def export_ecs_service_recommendations(params = {}, = {}) req = build_request(:export_ecs_service_recommendations, params) req.send_request() end |
#export_idle_recommendations(params = {}) ⇒ Types::ExportIdleRecommendationsResponse
Export optimization recommendations for your idle resources.
Recommendations are exported in a comma-separated values (CSV) file, and its metadata in a JavaScript Object Notation (JSON) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one idle resource export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1273 1274 1275 1276 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1273 def export_idle_recommendations(params = {}, = {}) req = build_request(:export_idle_recommendations, params) req.send_request() end |
#export_lambda_function_recommendations(params = {}) ⇒ Types::ExportLambdaFunctionRecommendationsResponse
Exports optimization recommendations for Lambda functions.
Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (JSON) (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one Lambda function export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1404 1405 1406 1407 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1404 def export_lambda_function_recommendations(params = {}, = {}) req = build_request(:export_lambda_function_recommendations, params) req.send_request() end |
#export_license_recommendations(params = {}) ⇒ Types::ExportLicenseRecommendationsResponse
Export optimization recommendations for your licenses.
Recommendations are exported in a comma-separated values (CSV) file, and its metadata in a JavaScript Object Notation (JSON) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one license export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1532 1533 1534 1535 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1532 def export_license_recommendations(params = {}, = {}) req = build_request(:export_license_recommendations, params) req.send_request() end |
#export_rds_database_recommendations(params = {}) ⇒ Types::ExportRDSDatabaseRecommendationsResponse
Export optimization recommendations for your Amazon Aurora and Amazon Relational Database Service (Amazon RDS) databases.
Recommendations are exported in a comma-separated values (CSV) file, and its metadata in a JavaScript Object Notation (JSON) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see [Exporting Recommendations] in the *Compute Optimizer User Guide*.
You can have only one Amazon Aurora or RDS export job in progress per Amazon Web Services Region.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
1672 1673 1674 1675 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1672 def export_rds_database_recommendations(params = {}, = {}) req = build_request(:export_rds_database_recommendations, params) req.send_request() end |
#get_auto_scaling_group_recommendations(params = {}) ⇒ Types::GetAutoScalingGroupRecommendationsResponse
Returns Auto Scaling group recommendations.
Compute Optimizer generates recommendations for Amazon EC2 Auto Scaling groups that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
1828 1829 1830 1831 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1828 def get_auto_scaling_group_recommendations(params = {}, = {}) req = build_request(:get_auto_scaling_group_recommendations, params) req.send_request() end |
#get_ebs_volume_recommendations(params = {}) ⇒ Types::GetEBSVolumeRecommendationsResponse
Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
Compute Optimizer generates recommendations for Amazon EBS volumes that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
1944 1945 1946 1947 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 1944 def get_ebs_volume_recommendations(params = {}, = {}) req = build_request(:get_ebs_volume_recommendations, params) req.send_request() end |
#get_ec2_instance_recommendations(params = {}) ⇒ Types::GetEC2InstanceRecommendationsResponse
Returns Amazon EC2 instance recommendations.
Compute Optimizer generates recommendations for Amazon Elastic Compute Cloud (Amazon EC2) instances that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
2097 2098 2099 2100 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2097 def get_ec2_instance_recommendations(params = {}, = {}) req = build_request(:get_ec2_instance_recommendations, params) req.send_request() end |
#get_ec2_recommendation_projected_metrics(params = {}) ⇒ Types::GetEC2RecommendationProjectedMetricsResponse
Returns the projected utilization metrics of Amazon EC2 instance recommendations.
<note markdown=“1”> The ‘Cpu` and `Memory` metrics are the only projected utilization metrics returned when you run this action. Additionally, the `Memory` metric is returned only for resources that have the unified CloudWatch agent installed on them. For more information, see [Enabling Memory Utilization with the CloudWatch Agent].
</note>
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/metrics.html#cw-agent
2170 2171 2172 2173 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2170 def get_ec2_recommendation_projected_metrics(params = {}, = {}) req = build_request(:get_ec2_recommendation_projected_metrics, params) req.send_request() end |
#get_ecs_service_recommendation_projected_metrics(params = {}) ⇒ Types::GetECSServiceRecommendationProjectedMetricsResponse
Returns the projected metrics of Amazon ECS service recommendations.
2228 2229 2230 2231 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2228 def get_ecs_service_recommendation_projected_metrics(params = {}, = {}) req = build_request(:get_ecs_service_recommendation_projected_metrics, params) req.send_request() end |
#get_ecs_service_recommendations(params = {}) ⇒ Types::GetECSServiceRecommendationsResponse
Returns Amazon ECS service recommendations.
Compute Optimizer generates recommendations for Amazon ECS services on Fargate that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
2355 2356 2357 2358 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2355 def get_ecs_service_recommendations(params = {}, = {}) req = build_request(:get_ecs_service_recommendations, params) req.send_request() end |
#get_effective_recommendation_preferences(params = {}) ⇒ Types::GetEffectiveRecommendationPreferencesResponse
Returns the recommendation preferences that are in effect for a given resource, such as enhanced infrastructure metrics. Considers all applicable preferences that you might have set at the resource, account, and organization level.
When you create a recommendation preference, you can set its status to ‘Active` or `Inactive`. Use this action to view the recommendation preferences that are in effect, or `Active`.
2410 2411 2412 2413 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2410 def get_effective_recommendation_preferences(params = {}, = {}) req = build_request(:get_effective_recommendation_preferences, params) req.send_request() end |
#get_enrollment_status(params = {}) ⇒ Types::GetEnrollmentStatusResponse
Returns the enrollment (opt in) status of an account to the Compute Optimizer service.
If the account is the management account of an organization, this action also confirms the enrollment status of member accounts of the organization. Use the GetEnrollmentStatusesForOrganization action to get detailed information about the enrollment status of member accounts of an organization.
2444 2445 2446 2447 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2444 def get_enrollment_status(params = {}, = {}) req = build_request(:get_enrollment_status, params) req.send_request() end |
#get_enrollment_statuses_for_organization(params = {}) ⇒ Types::GetEnrollmentStatusesForOrganizationResponse
Returns the Compute Optimizer enrollment (opt-in) status of organization member accounts, if your account is an organization management account.
To get the enrollment status of standalone accounts, use the GetEnrollmentStatus action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2504 2505 2506 2507 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2504 def get_enrollment_statuses_for_organization(params = {}, = {}) req = build_request(:get_enrollment_statuses_for_organization, params) req.send_request() end |
#get_idle_recommendations(params = {}) ⇒ Types::GetIdleRecommendationsResponse
Returns idle resource recommendations. Compute Optimizer generates recommendations for idle resources that meet a specific set of requirements. For more information, see [Resource requirements] in the *Compute Optimizer User Guide*
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
2609 2610 2611 2612 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2609 def get_idle_recommendations(params = {}, = {}) req = build_request(:get_idle_recommendations, params) req.send_request() end |
#get_lambda_function_recommendations(params = {}) ⇒ Types::GetLambdaFunctionRecommendationsResponse
Returns Lambda function recommendations.
Compute Optimizer generates recommendations for functions that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2727 2728 2729 2730 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2727 def get_lambda_function_recommendations(params = {}, = {}) req = build_request(:get_lambda_function_recommendations, params) req.send_request() end |
#get_license_recommendations(params = {}) ⇒ Types::GetLicenseRecommendationsResponse
Returns license recommendations for Amazon EC2 instances that run on a specific license.
Compute Optimizer generates recommendations for licenses that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
2836 2837 2838 2839 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2836 def get_license_recommendations(params = {}, = {}) req = build_request(:get_license_recommendations, params) req.send_request() end |
#get_rds_database_recommendation_projected_metrics(params = {}) ⇒ Types::GetRDSDatabaseRecommendationProjectedMetricsResponse
Returns the projected metrics of Aurora and RDS database recommendations.
2902 2903 2904 2905 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 2902 def get_rds_database_recommendation_projected_metrics(params = {}, = {}) req = build_request(:get_rds_database_recommendation_projected_metrics, params) req.send_request() end |
#get_rds_database_recommendations(params = {}) ⇒ Types::GetRDSDatabaseRecommendationsResponse
Returns Amazon Aurora and RDS database recommendations.
Compute Optimizer generates recommendations for Amazon Aurora and RDS databases that meet a specific set of requirements. For more information, see the [Supported resources and requirements] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
3061 3062 3063 3064 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3061 def get_rds_database_recommendations(params = {}, = {}) req = build_request(:get_rds_database_recommendations, params) req.send_request() end |
#get_recommendation_preferences(params = {}) ⇒ Types::GetRecommendationPreferencesResponse
Returns existing recommendation preferences, such as enhanced infrastructure metrics.
Use the ‘scope` parameter to specify which preferences to return. You can specify to return preferences for an organization, a specific account ID, or a specific EC2 instance or Auto Scaling group Amazon Resource Name (ARN).
For more information, see [Activating enhanced infrastructure metrics] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3162 3163 3164 3165 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3162 def get_recommendation_preferences(params = {}, = {}) req = build_request(:get_recommendation_preferences, params) req.send_request() end |
#get_recommendation_summaries(params = {}) ⇒ Types::GetRecommendationSummariesResponse
Returns the optimization findings for an account.
It returns the number of:
-
Amazon EC2 instances in an account that are ‘Underprovisioned`, `Overprovisioned`, or `Optimized`.
-
EC2Auto Scaling groups in an account that are ‘NotOptimized`, or `Optimized`.
-
Amazon EBS volumes in an account that are ‘NotOptimized`, or `Optimized`.
-
Lambda functions in an account that are ‘NotOptimized`, or `Optimized`.
-
Amazon ECS services in an account that are ‘Underprovisioned`, `Overprovisioned`, or `Optimized`.
-
Commercial software licenses in an account that are ‘InsufficientMetrics`, `NotOptimized` or `Optimized`.
-
Amazon Aurora and Amazon RDS databases in an account that are ‘Underprovisioned`, `Overprovisioned`, `Optimized`, or `NotOptimized`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3266 3267 3268 3269 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3266 def get_recommendation_summaries(params = {}, = {}) req = build_request(:get_recommendation_summaries, params) req.send_request() end |
#put_recommendation_preferences(params = {}) ⇒ Struct
Creates a new recommendation preference or updates an existing recommendation preference, such as enhanced infrastructure metrics.
For more information, see [Activating enhanced infrastructure metrics] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
3473 3474 3475 3476 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3473 def put_recommendation_preferences(params = {}, = {}) req = build_request(:put_recommendation_preferences, params) req.send_request() end |
#update_enrollment_status(params = {}) ⇒ Types::UpdateEnrollmentStatusResponse
Updates the enrollment (opt in and opt out) status of an account to the Compute Optimizer service.
If the account is a management account of an organization, this action can also be used to enroll member accounts of the organization.
You must have the appropriate permissions to opt in to Compute Optimizer, to view its recommendations, and to opt out. For more information, see [Controlling access with Amazon Web Services Identity and Access Management] in the *Compute Optimizer User Guide*.
When you opt in, Compute Optimizer automatically creates a service-linked role in your account to access its data. For more information, see [Using Service-Linked Roles for Compute Optimizer] in the *Compute Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/security-iam.html [2]: docs.aws.amazon.com/compute-optimizer/latest/ug/using-service-linked-roles.html
3549 3550 3551 3552 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3549 def update_enrollment_status(params = {}, = {}) req = build_request(:update_enrollment_status, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3578 3579 3580 |
# File 'lib/aws-sdk-computeoptimizer/client.rb', line 3578 def waiter_names [] end |