Class: Aws::ComputeOptimizer::Types::EBSEffectiveRecommendationPreferences

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the effective recommendation preferences for Amazon EBS volumes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#look_back_periodString

The number of days for which utilization metrics were analyzed for the volume.

Returns:

  • (String)


659
660
661
662
663
664
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 659

class EBSEffectiveRecommendationPreferences < Struct.new(
  :savings_estimation_mode,
  :look_back_period)
  SENSITIVE = []
  include Aws::Structure
end

#savings_estimation_modeTypes::EBSSavingsEstimationMode

Describes the savings estimation mode preference applied for calculating savings opportunity for Amazon EBS volumes.



659
660
661
662
663
664
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 659

class EBSEffectiveRecommendationPreferences < Struct.new(
  :savings_estimation_mode,
  :look_back_period)
  SENSITIVE = []
  include Aws::Structure
end