Class: Aws::ComputeOptimizer::Types::ECSEffectiveRecommendationPreferences
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::ECSEffectiveRecommendationPreferences
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the effective recommendation preferences for Amazon ECS services.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#look_back_period ⇒ String
The number of days the Amazon ECS service utilization metrics were analyzed.
-
#savings_estimation_mode ⇒ Types::ECSSavingsEstimationMode
Describes the savings estimation mode preference applied for calculating savings opportunity for Amazon ECS services.
Instance Attribute Details
#look_back_period ⇒ String
The number of days the Amazon ECS service utilization metrics were analyzed.
860 861 862 863 864 865 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 860 class ECSEffectiveRecommendationPreferences < Struct.new( :savings_estimation_mode, :look_back_period) SENSITIVE = [] include Aws::Structure end |
#savings_estimation_mode ⇒ Types::ECSSavingsEstimationMode
Describes the savings estimation mode preference applied for calculating savings opportunity for Amazon ECS services.
860 861 862 863 864 865 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 860 class ECSEffectiveRecommendationPreferences < Struct.new( :savings_estimation_mode, :look_back_period) SENSITIVE = [] include Aws::Structure end |