Class: Aws::ComputeOptimizer::Types::ECSServiceRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::ECSServiceRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes an Amazon ECS service recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the Amazon ECS service.
-
#current_performance_risk ⇒ String
The risk of the current Amazon ECS service not meeting the performance needs of its workloads.
-
#current_service_configuration ⇒ Types::ServiceConfiguration
The configuration of the current Amazon ECS service.
-
#effective_recommendation_preferences ⇒ Types::ECSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for Amazon ECS services.
-
#finding ⇒ String
The finding classification of an Amazon ECS service.
-
#finding_reason_codes ⇒ Array<String>
The reason for the finding classification of an Amazon ECS service.
-
#last_refresh_timestamp ⇒ Time
The timestamp of when the Amazon ECS service recommendation was last generated.
-
#launch_type ⇒ String
The launch type the Amazon ECS service is using.
-
#lookback_period_in_days ⇒ Float
The number of days the Amazon ECS service utilization metrics were analyzed.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the current Amazon ECS service.
-
#service_recommendation_options ⇒ Array<Types::ECSServiceRecommendationOption>
An array of objects that describe the recommendation options for the Amazon ECS service.
-
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your Amazon ECS service recommendations.
-
#utilization_metrics ⇒ Array<Types::ECSServiceUtilizationMetric>
An array of objects that describe the utilization metrics of the Amazon ECS service.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the Amazon ECS service.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#current_performance_risk ⇒ String
The risk of the current Amazon ECS service not meeting the performance needs of its workloads. The higher the risk, the more likely the current service can’t meet the performance requirements of its workload.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#current_service_configuration ⇒ Types::ServiceConfiguration
The configuration of the current Amazon ECS service.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#effective_recommendation_preferences ⇒ Types::ECSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for Amazon ECS services.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#finding ⇒ String
The finding classification of an Amazon ECS service.
Findings for Amazon ECS services include:
-
Underprovisioned— When Compute Optimizer detects that there’s not enough memory or CPU, an Amazon ECS service is considered under-provisioned. An under-provisioned service might result in poor application performance. -
Overprovisioned— When Compute Optimizer detects that there’s excessive memory or CPU, an Amazon ECS service is considered over-provisioned. An over-provisioned service might result in additional infrastructure costs. -
Optimized— When both the CPU and memory of your Amazon ECS service meet the performance requirements of your workload, the service is considered optimized.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#finding_reason_codes ⇒ Array<String>
The reason for the finding classification of an Amazon ECS service.
Finding reason codes for Amazon ECS services include:
-
CPUUnderprovisioned— The service CPU configuration can be sized up to enhance the performance of your workload. This is identified by analyzing the ‘CPUUtilization` metric of the current service during the look-back period. -
CPUOverprovisioned— The service CPU configuration can be sized down while still meeting the performance requirements of your workload. This is identified by analyzing the ‘CPUUtilization` metric of the current service during the look-back period. -
MemoryUnderprovisioned— The service memory configuration can be sized up to enhance the performance of your workload. This is identified by analyzing the ‘MemoryUtilization` metric of the current service during the look-back period. -
MemoryOverprovisioned— The service memory configuration can be sized down while still meeting the performance requirements of your workload. This is identified by analyzing the ‘MemoryUtilization` metric of the current service during the look-back period.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#last_refresh_timestamp ⇒ Time
The timestamp of when the Amazon ECS service recommendation was last generated.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#launch_type ⇒ String
The launch type the Amazon ECS service is using.
<note markdown=“1”> Compute Optimizer only supports the Fargate launch type.
</note>
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#lookback_period_in_days ⇒ Float
The number of days the Amazon ECS service utilization metrics were analyzed.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the current Amazon ECS service.
The following is the format of the ARN:
‘arn:aws:ecs:region:aws_account_id:service/cluster-name/service-name`
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#service_recommendation_options ⇒ Array<Types::ECSServiceRecommendationOption>
An array of objects that describe the recommendation options for the Amazon ECS service.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your Amazon ECS service recommendations.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#utilization_metrics ⇒ Array<Types::ECSServiceUtilizationMetric>
An array of objects that describe the utilization metrics of the Amazon ECS service.
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 1160 class ECSServiceRecommendation < Struct.new( :service_arn, :account_id, :current_service_configuration, :utilization_metrics, :lookback_period_in_days, :launch_type, :last_refresh_timestamp, :finding, :finding_reason_codes, :service_recommendation_options, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |