Class: Aws::ComputeOptimizer::Types::ExportECSServiceRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::ExportECSServiceRecommendationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The identification number of the export job.
-
#s3_destination ⇒ Types::S3Destination
Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.
Instance Attribute Details
#job_id ⇒ String
The identification number of the export job.
To view the status of an export job, use the DescribeRecommendationExportJobs action and specify the job ID.
2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2055 class ExportECSServiceRecommendationsResponse < Struct.new( :job_id, :s3_destination) SENSITIVE = [] include Aws::Structure end |
#s3_destination ⇒ Types::S3Destination
Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.
2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2055 class ExportECSServiceRecommendationsResponse < Struct.new( :job_id, :s3_destination) SENSITIVE = [] include Aws::Structure end |