Class: Aws::ComputeOptimizer::Types::ExportLambdaFunctionRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::ExportLambdaFunctionRecommendationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The identification number of the export job.
-
#s3_destination ⇒ Types::S3Destination
Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.
Instance Attribute Details
#job_id ⇒ String
The identification number of the export job.
Use the DescribeRecommendationExportJobs action, and specify the job ID to view the status of an export job.
2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2288 class ExportLambdaFunctionRecommendationsResponse < Struct.new( :job_id, :s3_destination) SENSITIVE = [] include Aws::Structure end |
#s3_destination ⇒ Types::S3Destination
Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.
2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2288 class ExportLambdaFunctionRecommendationsResponse < Struct.new( :job_id, :s3_destination) SENSITIVE = [] include Aws::Structure end |