Class: Aws::ComputeOptimizer::Types::GetAutoScalingGroupRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetAutoScalingGroupRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return Auto Scaling group recommendations.
-
#auto_scaling_group_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Auto Scaling groups for which to return recommendations.
-
#filters ⇒ Array<Types::Filter>
An array of objects to specify a filter that returns a more specific list of Auto Scaling group recommendations.
-
#max_results ⇒ Integer
The maximum number of Auto Scaling group recommendations to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of Auto Scaling group recommendations.
-
#recommendation_preferences ⇒ Types::RecommendationPreferences
An object to specify the preferences for the Auto Scaling group recommendations to return in the response.
Instance Attribute Details
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return Auto Scaling group recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return Auto Scaling group recommendations.
Only one account ID can be specified per request.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_group_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Auto Scaling groups for which to return recommendations.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
An array of objects to specify a filter that returns a more specific list of Auto Scaling group recommendations.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of Auto Scaling group recommendations to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of Auto Scaling group recommendations.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#recommendation_preferences ⇒ Types::RecommendationPreferences
An object to specify the preferences for the Auto Scaling group recommendations to return in the response.
2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2750 class GetAutoScalingGroupRecommendationsRequest < Struct.new( :account_ids, :auto_scaling_group_arns, :next_token, :max_results, :filters, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |