Class: Aws::ComputeOptimizer::Types::GetAutoScalingGroupRecommendationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_recommendationsArray<Types::AutoScalingGroupRecommendation>

An array of objects that describe Auto Scaling group recommendations.



2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2797

class GetAutoScalingGroupRecommendationsResponse < Struct.new(
  :next_token,
  :auto_scaling_group_recommendations,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::GetRecommendationError>

An array of objects that describe errors of the request.

For example, an error is returned if you request recommendations for an unsupported Auto Scaling group.

Returns:



2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2797

class GetAutoScalingGroupRecommendationsResponse < Struct.new(
  :next_token,
  :auto_scaling_group_recommendations,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to advance to the next page of Auto Scaling group recommendations.

This value is null when there are no more pages of Auto Scaling group recommendations to return.

Returns:

  • (String)


2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2797

class GetAutoScalingGroupRecommendationsResponse < Struct.new(
  :next_token,
  :auto_scaling_group_recommendations,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end