Class: Aws::ComputeOptimizer::Types::GetEBSVolumeRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEBSVolumeRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return volume recommendations.
-
#filters ⇒ Array<Types::EBSFilter>
An array of objects to specify a filter that returns a more specific list of volume recommendations.
-
#max_results ⇒ Integer
The maximum number of volume recommendations to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of volume recommendations.
-
#volume_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the volumes for which to return recommendations.
Instance Attribute Details
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return volume recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return volume recommendations.
Only one account ID can be specified per request.
2840 2841 2842 2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2840 class GetEBSVolumeRecommendationsRequest < Struct.new( :volume_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::EBSFilter>
An array of objects to specify a filter that returns a more specific list of volume recommendations.
2840 2841 2842 2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2840 class GetEBSVolumeRecommendationsRequest < Struct.new( :volume_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of volume recommendations to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
2840 2841 2842 2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2840 class GetEBSVolumeRecommendationsRequest < Struct.new( :volume_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of volume recommendations.
2840 2841 2842 2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2840 class GetEBSVolumeRecommendationsRequest < Struct.new( :volume_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#volume_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the volumes for which to return recommendations.
2840 2841 2842 2843 2844 2845 2846 2847 2848 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2840 class GetEBSVolumeRecommendationsRequest < Struct.new( :volume_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |