Class: Aws::ComputeOptimizer::Types::GetEBSVolumeRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEBSVolumeRecommendationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Array<Types::GetRecommendationError>
An array of objects that describe errors of the request.
-
#next_token ⇒ String
The token to use to advance to the next page of volume recommendations.
-
#volume_recommendations ⇒ Array<Types::VolumeRecommendation>
An array of objects that describe volume recommendations.
Instance Attribute Details
#errors ⇒ Array<Types::GetRecommendationError>
An array of objects that describe errors of the request.
For example, an error is returned if you request recommendations for an unsupported volume.
2871 2872 2873 2874 2875 2876 2877 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2871 class GetEBSVolumeRecommendationsResponse < Struct.new( :next_token, :volume_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to advance to the next page of volume recommendations.
This value is null when there are no more pages of volume recommendations to return.
2871 2872 2873 2874 2875 2876 2877 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2871 class GetEBSVolumeRecommendationsResponse < Struct.new( :next_token, :volume_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |
#volume_recommendations ⇒ Array<Types::VolumeRecommendation>
An array of objects that describe volume recommendations.
2871 2872 2873 2874 2875 2876 2877 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2871 class GetEBSVolumeRecommendationsResponse < Struct.new( :next_token, :volume_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |