Class: Aws::ComputeOptimizer::Types::GetEC2InstanceRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEC2InstanceRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return instance recommendations.
-
#filters ⇒ Array<Types::Filter>
An array of objects to specify a filter that returns a more specific list of instance recommendations.
-
#instance_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the instances for which to return recommendations.
-
#max_results ⇒ Integer
The maximum number of instance recommendations to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of instance recommendations.
-
#recommendation_preferences ⇒ Types::RecommendationPreferences
An object to specify the preferences for the Amazon EC2 instance recommendations to return in the response.
Instance Attribute Details
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return instance recommendations.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return instance recommendations.
Only one account ID can be specified per request.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
An array of objects to specify a filter that returns a more specific list of instance recommendations.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#instance_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the instances for which to return recommendations.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of instance recommendations to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of instance recommendations.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#recommendation_preferences ⇒ Types::RecommendationPreferences
An object to specify the preferences for the Amazon EC2 instance recommendations to return in the response.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2919 class GetEC2InstanceRecommendationsRequest < Struct.new( :instance_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |