Class: Aws::ComputeOptimizer::Types::GetEnrollmentStatusesForOrganizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEnrollmentStatusesForOrganizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::EnrollmentFilter>
An array of objects to specify a filter that returns a more specific list of account enrollment statuses.
-
#max_results ⇒ Integer
The maximum number of account enrollment statuses to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of account enrollment statuses.
Instance Attribute Details
#filters ⇒ Array<Types::EnrollmentFilter>
An array of objects to specify a filter that returns a more specific list of account enrollment statuses.
3309 3310 3311 3312 3313 3314 3315 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3309 class GetEnrollmentStatusesForOrganizationRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of account enrollment statuses to return with a single request. You can specify up to 100 statuses to return with each request.
To retrieve the remaining results, make another request with the
returned nextToken value.
3309 3310 3311 3312 3313 3314 3315 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3309 class GetEnrollmentStatusesForOrganizationRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of account enrollment statuses.
3309 3310 3311 3312 3313 3314 3315 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3309 class GetEnrollmentStatusesForOrganizationRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |