Class: Aws::ComputeOptimizer::Types::GetEnrollmentStatusesForOrganizationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_enrollment_statusesArray<Types::AccountEnrollmentStatus>

An array of objects that describe the enrollment statuses of organization member accounts.

Returns:



3332
3333
3334
3335
3336
3337
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3332

class GetEnrollmentStatusesForOrganizationResponse < Struct.new(
  :account_enrollment_statuses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to advance to the next page of account enrollment statuses.

This value is null when there are no more pages of account enrollment statuses to return.

Returns:

  • (String)


3332
3333
3334
3335
3336
3337
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3332

class GetEnrollmentStatusesForOrganizationResponse < Struct.new(
  :account_enrollment_statuses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end