Class: Aws::ComputeOptimizer::Types::GetIdleRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

Return the idle resource recommendations to the specified Amazon Web Services account IDs.

If your account is the management account or the delegated administrator of an organization, use this parameter to return the idle resource recommendations to specific member accounts.

You can only specify one account ID per request.

Returns:

  • (Array<String>)


3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::IdleRecommendationFilter>

An array of objects to specify a filter that returns a more specific list of idle resource recommendations.



3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of idle resource recommendations to return with a single request.

To retrieve the remaining results, make another request with the returned ‘nextToken` value.

Returns:

  • (Integer)


3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to advance to the next page of idle resource recommendations.

Returns:

  • (String)


3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#order_byTypes::OrderBy

The order to sort the idle resource recommendations.

Returns:



3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

The ARN that identifies the idle resource.

Returns:

  • (Array<String>)


3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3364

class GetIdleRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end