Class: Aws::ComputeOptimizer::Types::GetRDSDatabaseRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRDSDatabaseRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
Return the Amazon Aurora and RDS database recommendations to the specified Amazon Web Services account IDs.
-
#filters ⇒ Array<Types::RDSDBRecommendationFilter>
An array of objects to specify a filter that returns a more specific list of Amazon Aurora and RDS database recommendations.
-
#max_results ⇒ Integer
The maximum number of Amazon Aurora and RDS database recommendations to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of Amazon Aurora and RDS database recommendations.
-
#recommendation_preferences ⇒ Types::RecommendationPreferences
Describes the recommendation preferences to return in the response of a GetAutoScalingGroupRecommendations, GetEC2InstanceRecommendations, GetEC2RecommendationProjectedMetrics, GetRDSDatabaseRecommendations, and GetRDSDatabaseRecommendationProjectedMetrics request.
-
#resource_arns ⇒ Array<String>
The ARN that identifies the Amazon Aurora or RDS database.
Instance Attribute Details
#account_ids ⇒ Array<String>
Return the Amazon Aurora and RDS database recommendations to the specified Amazon Web Services account IDs.
If your account is the management account or the delegated administrator of an organization, use this parameter to return the Amazon Aurora and RDS database recommendations to specific member accounts.
You can only specify one account ID per request.
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::RDSDBRecommendationFilter>
An array of objects to specify a filter that returns a more specific list of Amazon Aurora and RDS database recommendations.
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of Amazon Aurora and RDS database recommendations to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of Amazon Aurora and RDS database recommendations.
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#recommendation_preferences ⇒ Types::RecommendationPreferences
Describes the recommendation preferences to return in the response of a GetAutoScalingGroupRecommendations, GetEC2InstanceRecommendations, GetEC2RecommendationProjectedMetrics, GetRDSDatabaseRecommendations, and GetRDSDatabaseRecommendationProjectedMetrics request.
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
The ARN that identifies the Amazon Aurora or RDS database.
The following is the format of the ARN:
‘arn:aws:rds:region:accountId:db:resourceName`
The following is the format of a DB Cluster ARN:
‘arn:aws:rds:region:accountId:cluster:resourceName`
3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3670 class GetRDSDatabaseRecommendationsRequest < Struct.new( :resource_arns, :next_token, :max_results, :filters, :account_ids, :recommendation_preferences) SENSITIVE = [] include Aws::Structure end |