Class: Aws::ComputeOptimizer::Types::GetRecommendationPreferencesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRecommendationPreferencesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to advance to the next page of recommendation preferences.
-
#recommendation_preferences_details ⇒ Array<Types::RecommendationPreferencesDetail>
An array of objects that describe recommendation preferences.
Instance Attribute Details
#next_token ⇒ String
The token to use to advance to the next page of recommendation preferences.
This value is null when there are no more pages of recommendation preferences to return.
3795 3796 3797 3798 3799 3800 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3795 class GetRecommendationPreferencesResponse < Struct.new( :next_token, :recommendation_preferences_details) SENSITIVE = [] include Aws::Structure end |
#recommendation_preferences_details ⇒ Array<Types::RecommendationPreferencesDetail>
An array of objects that describe recommendation preferences.
3795 3796 3797 3798 3799 3800 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3795 class GetRecommendationPreferencesResponse < Struct.new( :next_token, :recommendation_preferences_details) SENSITIVE = [] include Aws::Structure end |