Class: Aws::ComputeOptimizer::Types::GetRecommendationSummariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRecommendationSummariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return recommendation summaries.
-
#max_results ⇒ Integer
The maximum number of recommendation summaries to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of recommendation summaries.
Instance Attribute Details
#account_ids ⇒ Array<String>
The ID of the Amazon Web Services account for which to return recommendation summaries.
If your account is the management account of an organization, use this parameter to specify the member account for which you want to return recommendation summaries.
Only one account ID can be specified per request.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3827 class GetRecommendationSummariesRequest < Struct.new( :account_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of recommendation summaries to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3827 class GetRecommendationSummariesRequest < Struct.new( :account_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of recommendation summaries.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3827 class GetRecommendationSummariesRequest < Struct.new( :account_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |