Class: Aws::ComputeOptimizer::Types::GetRecommendationSummariesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRecommendationSummariesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to advance to the next page of recommendation summaries.
-
#recommendation_summaries ⇒ Array<Types::RecommendationSummary>
An array of objects that summarize a recommendation.
Instance Attribute Details
#next_token ⇒ String
The token to use to advance to the next page of recommendation summaries.
This value is null when there are no more pages of recommendation summaries to return.
3835 3836 3837 3838 3839 3840 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3835 class GetRecommendationSummariesResponse < Struct.new( :next_token, :recommendation_summaries) SENSITIVE = [] include Aws::Structure end |
#recommendation_summaries ⇒ Array<Types::RecommendationSummary>
An array of objects that summarize a recommendation.
3835 3836 3837 3838 3839 3840 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3835 class GetRecommendationSummariesResponse < Struct.new( :next_token, :recommendation_summaries) SENSITIVE = [] include Aws::Structure end |