Class: Aws::ComputeOptimizer::Types::IdleSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the findings summary of the idle resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the finding group for the idle resources.

Returns:

  • (String)


4132
4133
4134
4135
4136
4137
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4132

class IdleSummary < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The count of idle resources in the finding group.

Returns:

  • (Float)


4132
4133
4134
4135
4136
4137
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4132

class IdleSummary < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end