Class: Aws::ComputeOptimizer::Types::IdleUtilizationMetric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the utilization metric of an idle resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimensionsArray<Types::IdleDimension>

The dimensions of the utilization metric.

Returns:



4162
4163
4164
4165
4166
4167
4168
4169
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4162

class IdleUtilizationMetric < Struct.new(
  :name,
  :statistic,
  :value,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the utilization metric.

Returns:

  • (String)


4162
4163
4164
4165
4166
4167
4168
4169
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4162

class IdleUtilizationMetric < Struct.new(
  :name,
  :statistic,
  :value,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end

#statisticString

The statistic of the utilization metric.

The Compute Optimizer API, Command Line Interface (CLI), and SDKs return utilization metrics using only the ‘Maximum` statistic, which is the highest value observed during the specified period.

The Compute Optimizer console displays graphs for some utilization metrics using the ‘Average` statistic, which is the value of `Sum` / `SampleCount` during the specified period. For more information, see

Viewing resource recommendations][1

in the *Compute Optimizer User

Guide*. You can also get averaged utilization metric data for your resources using Amazon CloudWatch. For more information, see the [Amazon CloudWatch User Guide].

[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/viewing-recommendations.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/WhatIsCloudWatch.html

Returns:

  • (String)


4162
4163
4164
4165
4166
4167
4168
4169
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4162

class IdleUtilizationMetric < Struct.new(
  :name,
  :statistic,
  :value,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The value of the utilization metric.

Returns:

  • (Float)


4162
4163
4164
4165
4166
4167
4168
4169
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4162

class IdleUtilizationMetric < Struct.new(
  :name,
  :statistic,
  :value,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end