Class: Aws::ComputeOptimizer::Types::InstanceEstimatedMonthlySavings
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::InstanceEstimatedMonthlySavings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
An object that describes the estimated monthly savings possible by adopting Compute Optimizer’s Amazon EC2 instance recommendations. This is based on the Savings Plans and Reserved Instances pricing discounts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency of the estimated monthly savings.
-
#value ⇒ Float
The value of the estimated monthly savings.
Instance Attribute Details
#currency ⇒ String
The currency of the estimated monthly savings.
4240 4241 4242 4243 4244 4245 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4240 class InstanceEstimatedMonthlySavings < Struct.new( :currency, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the estimated monthly savings.
4240 4241 4242 4243 4244 4245 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4240 class InstanceEstimatedMonthlySavings < Struct.new( :currency, :value) SENSITIVE = [] include Aws::Structure end |