Class: Aws::ComputeOptimizer::Types::InstanceSavingsOpportunityAfterDiscounts

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the savings opportunity for instance recommendations after applying the Savings Plans and Reserved Instances discounts.

Savings opportunity after discounts represents the estimated monthly savings you can achieve by implementing Compute Optimizer recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#estimated_monthly_savingsTypes::InstanceEstimatedMonthlySavings

An object that describes the estimated monthly savings possible by adopting Compute Optimizer’s Amazon EC2 instance recommendations. This is based on pricing after applying the Savings Plans and Reserved Instances discounts.



4790
4791
4792
4793
4794
4795
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4790

class InstanceSavingsOpportunityAfterDiscounts < Struct.new(
  :savings_opportunity_percentage,
  :estimated_monthly_savings)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunity_percentageFloat

The estimated monthly savings possible as a percentage of monthly cost after applying the Savings Plans and Reserved Instances discounts. This saving can be achieved by adopting Compute Optimizer’s EC2 instance recommendations.

Returns:

  • (Float)


4790
4791
4792
4793
4794
4795
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4790

class InstanceSavingsOpportunityAfterDiscounts < Struct.new(
  :savings_opportunity_percentage,
  :estimated_monthly_savings)
  SENSITIVE = []
  include Aws::Structure
end