Class: Aws::ComputeOptimizer::Types::LambdaEstimatedMonthlySavings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the estimated monthly savings possible for Lambda functions by adopting Compute Optimizer recommendations. This is based on Lambda functions pricing after applying Savings Plans discounts.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currencyString

The currency of the estimated monthly savings.

Returns:

  • (String)


4898
4899
4900
4901
4902
4903
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4898

class LambdaEstimatedMonthlySavings < Struct.new(
  :currency,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The value of the estimated monthly savings.

Returns:

  • (Float)


4898
4899
4900
4901
4902
4903
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4898

class LambdaEstimatedMonthlySavings < Struct.new(
  :currency,
  :value)
  SENSITIVE = []
  include Aws::Structure
end