Class: Aws::ComputeOptimizer::Types::LambdaFunctionMemoryRecommendationOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes a recommendation option for an Lambda function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#memory_sizeInteger

The memory size, in MB, of the function recommendation option.

Returns:

  • (Integer)


4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4937

class LambdaFunctionMemoryRecommendationOption < Struct.new(
  :rank,
  :memory_size,
  :projected_utilization_metrics,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#projected_utilization_metricsArray<Types::LambdaFunctionMemoryProjectedMetric>

An array of objects that describe the projected utilization metrics of the function recommendation option.



4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4937

class LambdaFunctionMemoryRecommendationOption < Struct.new(
  :rank,
  :memory_size,
  :projected_utilization_metrics,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#rankInteger

The rank of the function recommendation option.

The top recommendation option is ranked as ‘1`.

Returns:

  • (Integer)


4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4937

class LambdaFunctionMemoryRecommendationOption < Struct.new(
  :rank,
  :memory_size,
  :projected_utilization_metrics,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunityTypes::SavingsOpportunity

An object that describes the savings opportunity for the Lambda function recommendation option. Savings opportunity includes the estimated monthly savings amount and percentage.



4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4937

class LambdaFunctionMemoryRecommendationOption < Struct.new(
  :rank,
  :memory_size,
  :projected_utilization_metrics,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunity_after_discountsTypes::LambdaSavingsOpportunityAfterDiscounts

An object that describes the savings opportunity for the Lambda recommendation option which includes Saving Plans discounts. Savings opportunity includes the estimated monthly savings and percentage.



4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 4937

class LambdaFunctionMemoryRecommendationOption < Struct.new(
  :rank,
  :memory_size,
  :projected_utilization_metrics,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end