Class: Aws::ComputeOptimizer::Types::LambdaSavingsOpportunityAfterDiscounts
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::LambdaSavingsOpportunityAfterDiscounts
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the savings opportunity for Lambda functions recommendations after applying Savings Plans discounts.
Savings opportunity represents the estimated monthly savings after applying Savings Plans discounts. You can achieve this by implementing a given Compute Optimizer recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#estimated_monthly_savings ⇒ Types::LambdaEstimatedMonthlySavings
The estimated monthly savings possible by adopting Compute Optimizer’s Lambda function recommendations.
-
#savings_opportunity_percentage ⇒ Float
The estimated monthly savings possible as a percentage of monthly cost by adopting Compute Optimizer’s Lambda function recommendations.
Instance Attribute Details
#estimated_monthly_savings ⇒ Types::LambdaEstimatedMonthlySavings
The estimated monthly savings possible by adopting Compute Optimizer’s Lambda function recommendations. This includes any applicable Savings Plans discounts.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 5271 class LambdaSavingsOpportunityAfterDiscounts < Struct.new( :savings_opportunity_percentage, :estimated_monthly_savings) SENSITIVE = [] include Aws::Structure end |
#savings_opportunity_percentage ⇒ Float
The estimated monthly savings possible as a percentage of monthly cost by adopting Compute Optimizer’s Lambda function recommendations. This includes any applicable Savings Plans discounts.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 5271 class LambdaSavingsOpportunityAfterDiscounts < Struct.new( :savings_opportunity_percentage, :estimated_monthly_savings) SENSITIVE = [] include Aws::Structure end |