Class: Aws::ComputeOptimizer::Types::RDSDatabaseProjectedMetric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the projected metrics of an Amazon Aurora and RDS database recommendation option.

To determine the performance difference between your current Amazon Aurora and RDS database and the recommended option, compare the metric data of your service against its projected metric data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the projected metric.

Returns:

  • (String)


6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6375

class RDSDatabaseProjectedMetric < Struct.new(
  :name,
  :timestamps,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#timestampsArray<Time>

The timestamps of the projected metric.

Returns:

  • (Array<Time>)


6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6375

class RDSDatabaseProjectedMetric < Struct.new(
  :name,
  :timestamps,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Float>

The values for the projected metric.

Returns:

  • (Array<Float>)


6375
6376
6377
6378
6379
6380
6381
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6375

class RDSDatabaseProjectedMetric < Struct.new(
  :name,
  :timestamps,
  :values)
  SENSITIVE = []
  include Aws::Structure
end