Class: Aws::ComputeOptimizer::Types::RDSInstanceSavingsOpportunityAfterDiscounts
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSInstanceSavingsOpportunityAfterDiscounts
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the savings opportunity for DB instance recommendations after applying Savings Plans discounts.
Savings opportunity represents the estimated monthly savings after applying Savings Plans discounts. You can achieve this by implementing a given Compute Optimizer recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#estimated_monthly_savings ⇒ Types::RDSInstanceEstimatedMonthlySavings
The estimated monthly savings possible by adopting Compute Optimizer’s DB instance recommendations.
-
#savings_opportunity_percentage ⇒ Float
The estimated monthly savings possible as a percentage of monthly cost by adopting Compute Optimizer’s DB instance recommendations.
Instance Attribute Details
#estimated_monthly_savings ⇒ Types::RDSInstanceEstimatedMonthlySavings
The estimated monthly savings possible by adopting Compute Optimizer’s DB instance recommendations. This includes any applicable Savings Plans discounts.
6463 6464 6465 6466 6467 6468 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6463 class RDSInstanceSavingsOpportunityAfterDiscounts < Struct.new( :savings_opportunity_percentage, :estimated_monthly_savings) SENSITIVE = [] include Aws::Structure end |
#savings_opportunity_percentage ⇒ Float
The estimated monthly savings possible as a percentage of monthly cost by adopting Compute Optimizer’s DB instance recommendations. This includes any applicable Savings Plans discounts.
6463 6464 6465 6466 6467 6468 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6463 class RDSInstanceSavingsOpportunityAfterDiscounts < Struct.new( :savings_opportunity_percentage, :estimated_monthly_savings) SENSITIVE = [] include Aws::Structure end |