Class: Aws::ComputeOptimizer::Types::RDSStorageEstimatedMonthlySavings
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSStorageEstimatedMonthlySavings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the estimated monthly savings possible for DB instance storage by adopting Compute Optimizer recommendations. This is based on DB instance pricing after applying Savings Plans discounts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency of the estimated monthly savings.
-
#value ⇒ Float
The value of the estimated monthly savings for DB instance storage.
Instance Attribute Details
#currency ⇒ String
The currency of the estimated monthly savings.
6524 6525 6526 6527 6528 6529 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6524 class RDSStorageEstimatedMonthlySavings < Struct.new( :currency, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the estimated monthly savings for DB instance storage.
6524 6525 6526 6527 6528 6529 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6524 class RDSStorageEstimatedMonthlySavings < Struct.new( :currency, :value) SENSITIVE = [] include Aws::Structure end |