Class: Aws::ComputeOptimizer::Types::RDSStorageSavingsOpportunityAfterDiscounts

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the savings opportunity for Amazon RDS storage recommendations after applying Savings Plans discounts.

Savings opportunity represents the estimated monthly savings after applying Savings Plans discounts. You can achieve this by implementing a given Compute Optimizer recommendation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#estimated_monthly_savingsTypes::RDSStorageEstimatedMonthlySavings

The estimated monthly savings possible by adopting Compute Optimizer’s DB instance storage recommendations. This includes any applicable Savings Plans discounts.

Returns:



6567
6568
6569
6570
6571
6572
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6567

class RDSStorageSavingsOpportunityAfterDiscounts < Struct.new(
  :savings_opportunity_percentage,
  :estimated_monthly_savings)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunity_percentageFloat

The estimated monthly savings possible as a percentage of monthly cost by adopting Compute Optimizer’s DB instance storage recommendations. This includes any applicable Savings Plans discounts.

Returns:



6567
6568
6569
6570
6571
6572
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6567

class RDSStorageSavingsOpportunityAfterDiscounts < Struct.new(
  :savings_opportunity_percentage,
  :estimated_monthly_savings)
  SENSITIVE = []
  include Aws::Structure
end