Class: Aws::ComputeOptimizer::Types::VolumeRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::VolumeRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes an Amazon Elastic Block Store (Amazon EBS) volume recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the volume.
-
#current_configuration ⇒ Types::VolumeConfiguration
An array of objects that describe the current configuration of the volume.
-
#current_performance_risk ⇒ String
The risk of the current EBS volume not meeting the performance needs of its workloads.
-
#effective_recommendation_preferences ⇒ Types::EBSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for Amazon EBS volume.
-
#finding ⇒ String
The finding classification of the volume.
-
#last_refresh_timestamp ⇒ Time
The timestamp of when the volume recommendation was last generated.
-
#look_back_period_in_days ⇒ Float
The number of days for which utilization metrics were analyzed for the volume.
-
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your Amazon EBS volume recommendations.
-
#utilization_metrics ⇒ Array<Types::EBSUtilizationMetric>
An array of objects that describe the utilization metrics of the volume.
-
#volume_arn ⇒ String
The Amazon Resource Name (ARN) of the current volume.
-
#volume_recommendation_options ⇒ Array<Types::VolumeRecommendationOption>
An array of objects that describe the recommendation options for the volume.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#current_configuration ⇒ Types::VolumeConfiguration
An array of objects that describe the current configuration of the volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#current_performance_risk ⇒ String
The risk of the current EBS volume not meeting the performance needs of its workloads. The higher the risk, the more likely the current EBS volume doesn’t have sufficient capacity.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#effective_recommendation_preferences ⇒ Types::EBSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for Amazon EBS volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#finding ⇒ String
The finding classification of the volume.
Findings for volumes include:
-
NotOptimized—A volume is considered not optimized when Compute Optimizer identifies a recommendation that can provide better performance for your workload. -
Optimized—An volume is considered optimized when Compute Optimizer determines that the volume is correctly provisioned to run your workload based on the chosen volume type. For optimized resources, Compute Optimizer might recommend a new generation volume type.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#last_refresh_timestamp ⇒ Time
The timestamp of when the volume recommendation was last generated.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#look_back_period_in_days ⇒ Float
The number of days for which utilization metrics were analyzed for the volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your Amazon EBS volume recommendations.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#utilization_metrics ⇒ Array<Types::EBSUtilizationMetric>
An array of objects that describe the utilization metrics of the volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#volume_arn ⇒ String
The Amazon Resource Name (ARN) of the current volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |
#volume_recommendation_options ⇒ Array<Types::VolumeRecommendationOption>
An array of objects that describe the recommendation options for the volume.
7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 7609 class VolumeRecommendation < Struct.new( :volume_arn, :account_id, :current_configuration, :finding, :utilization_metrics, :look_back_period_in_days, :volume_recommendation_options, :last_refresh_timestamp, :current_performance_risk, :effective_recommendation_preferences, :tags) SENSITIVE = [] include Aws::Structure end |