Class: Aws::ComputeOptimizer::Types::EBSEffectiveRecommendationPreferences
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::EBSEffectiveRecommendationPreferences
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the effective recommendation preferences for Amazon EBS volumes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#look_back_period ⇒ String
The number of days for which utilization metrics were analyzed for the volume.
-
#savings_estimation_mode ⇒ Types::EBSSavingsEstimationMode
Describes the savings estimation mode preference applied for calculating savings opportunity for Amazon EBS volumes.
Instance Attribute Details
#look_back_period ⇒ String
The number of days for which utilization metrics were analyzed for the volume.
659 660 661 662 663 664 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 659 class EBSEffectiveRecommendationPreferences < Struct.new( :savings_estimation_mode, :look_back_period) SENSITIVE = [] include Aws::Structure end |
#savings_estimation_mode ⇒ Types::EBSSavingsEstimationMode
Describes the savings estimation mode preference applied for calculating savings opportunity for Amazon EBS volumes.
659 660 661 662 663 664 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 659 class EBSEffectiveRecommendationPreferences < Struct.new( :savings_estimation_mode, :look_back_period) SENSITIVE = [] include Aws::Structure end |