Class: Aws::ComputeOptimizer::Types::EBSUtilizationMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::EBSUtilizationMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes a utilization metric of an Amazon Elastic Block Store (Amazon EBS) volume.
Compare the utilization metric data of your resource against its projected utilization metric data to determine the performance difference between your current resource and the recommended option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the utilization metric.
-
#statistic ⇒ String
The statistic of the utilization metric.
-
#value ⇒ Float
The value of the utilization metric.
Instance Attribute Details
#name ⇒ String
The name of the utilization metric.
The following utilization metrics are available:
-
‘VolumeReadOpsPerSecond` - The completed read operations per second from the volume in a specified period of time.
Unit: Count
-
‘VolumeWriteOpsPerSecond` - The completed write operations per second to the volume in a specified period of time.
Unit: Count
-
‘VolumeReadBytesPerSecond` - The bytes read per second from the volume in a specified period of time.
Unit: Bytes
-
‘VolumeWriteBytesPerSecond` - The bytes written to the volume in a specified period of time.
Unit: Bytes
-
‘VolumeIOPSExceeded` - Indicates whether the volume’s provisioned IOPS performance was exceeded in a specified period of time. A value of ‘1` means the provisioned IOPS were exceeded; a value of `0` means they were not.
Unit: None
-
‘VolumeThroughputExceeded` - Indicates whether the volume’s provisioned throughput performance was exceeded in a specified period of time. A value of ‘1` means the provisioned throughput was exceeded; a value of `0` means it was not.
Unit: None
851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 851 class EBSUtilizationMetric < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic of the utilization metric.
The Compute Optimizer API, Command Line Interface (CLI), and SDKs return utilization metrics using only the ‘Maximum` statistic, which is the highest value observed during the specified period.
The Compute Optimizer console displays graphs for some utilization metrics using the ‘Average` statistic, which is the value of `Sum` / `SampleCount` during the specified period. For more information, see
- Viewing resource recommendations][1
-
in the *Compute Optimizer User
Guide*. You can also get averaged utilization metric data for your resources using Amazon CloudWatch. For more information, see the [Amazon CloudWatch User Guide].
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/viewing-recommendations.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/WhatIsCloudWatch.html
851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 851 class EBSUtilizationMetric < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the utilization metric.
851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 851 class EBSUtilizationMetric < Struct.new( :name, :statistic, :value) SENSITIVE = [] include Aws::Structure end |