Class: Aws::ComputeOptimizer::Types::GetAutoScalingGroupRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetAutoScalingGroupRecommendationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_recommendations ⇒ Array<Types::AutoScalingGroupRecommendation>
An array of objects that describe Auto Scaling group recommendations.
-
#errors ⇒ Array<Types::GetRecommendationError>
An array of objects that describe errors of the request.
-
#next_token ⇒ String
The token to use to advance to the next page of Auto Scaling group recommendations.
Instance Attribute Details
#auto_scaling_group_recommendations ⇒ Array<Types::AutoScalingGroupRecommendation>
An array of objects that describe Auto Scaling group recommendations.
2783 2784 2785 2786 2787 2788 2789 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2783 class GetAutoScalingGroupRecommendationsResponse < Struct.new( :next_token, :auto_scaling_group_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::GetRecommendationError>
An array of objects that describe errors of the request.
For example, an error is returned if you request recommendations for an unsupported Auto Scaling group.
2783 2784 2785 2786 2787 2788 2789 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2783 class GetAutoScalingGroupRecommendationsResponse < Struct.new( :next_token, :auto_scaling_group_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to advance to the next page of Auto Scaling group recommendations.
This value is null when there are no more pages of Auto Scaling group recommendations to return.
2783 2784 2785 2786 2787 2788 2789 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 2783 class GetAutoScalingGroupRecommendationsResponse < Struct.new( :next_token, :auto_scaling_group_recommendations, :errors) SENSITIVE = [] include Aws::Structure end |