Class: Aws::ComputeOptimizer::Types::GetECSServiceRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetECSServiceRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
Return the Amazon ECS service recommendations to the specified Amazon Web Services account IDs.
-
#filters ⇒ Array<Types::ECSServiceRecommendationFilter>
An array of objects to specify a filter that returns a more specific list of Amazon ECS service recommendations.
-
#max_results ⇒ Integer
The maximum number of Amazon ECS service recommendations to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of Amazon ECS service recommendations.
-
#service_arns ⇒ Array<String>
The ARN that identifies the Amazon ECS service.
Instance Attribute Details
#account_ids ⇒ Array<String>
Return the Amazon ECS service recommendations to the specified Amazon Web Services account IDs.
If your account is the management account or the delegated administrator of an organization, use this parameter to return the Amazon ECS service recommendations to specific member accounts.
You can only specify one account ID per request.
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3097 class GetECSServiceRecommendationsRequest < Struct.new( :service_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::ECSServiceRecommendationFilter>
An array of objects to specify a filter that returns a more specific list of Amazon ECS service recommendations.
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3097 class GetECSServiceRecommendationsRequest < Struct.new( :service_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of Amazon ECS service recommendations to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3097 class GetECSServiceRecommendationsRequest < Struct.new( :service_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of Amazon ECS service recommendations.
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3097 class GetECSServiceRecommendationsRequest < Struct.new( :service_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |
#service_arns ⇒ Array<String>
The ARN that identifies the Amazon ECS service.
The following is the format of the ARN:
‘arn:aws:ecs:region:aws_account_id:service/cluster-name/service-name`
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3097 class GetECSServiceRecommendationsRequest < Struct.new( :service_arns, :next_token, :max_results, :filters, :account_ids) SENSITIVE = [] include Aws::Structure end |