Class: Aws::ComputeOptimizer::Types::GetEffectiveRecommendationPreferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEffectiveRecommendationPreferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource for which to confirm effective recommendation preferences.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource for which to confirm effective recommendation preferences. Only EC2 instance and Auto Scaling group ARNs are currently supported.
3125 3126 3127 3128 3129 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3125 class GetEffectiveRecommendationPreferencesRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |