Class: Aws::ComputeOptimizer::Types::GetEnrollmentStatusesForOrganizationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetEnrollmentStatusesForOrganizationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_enrollment_statuses ⇒ Array<Types::AccountEnrollmentStatus>
An array of objects that describe the enrollment statuses of organization member accounts.
-
#next_token ⇒ String
The token to use to advance to the next page of account enrollment statuses.
Instance Attribute Details
#account_enrollment_statuses ⇒ Array<Types::AccountEnrollmentStatus>
An array of objects that describe the enrollment statuses of organization member accounts.
3318 3319 3320 3321 3322 3323 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3318 class GetEnrollmentStatusesForOrganizationResponse < Struct.new( :account_enrollment_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to advance to the next page of account enrollment statuses.
This value is null when there are no more pages of account enrollment statuses to return.
3318 3319 3320 3321 3322 3323 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3318 class GetEnrollmentStatusesForOrganizationResponse < Struct.new( :account_enrollment_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |