Class: Aws::ComputeOptimizer::Types::GetLambdaFunctionRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetLambdaFunctionRecommendationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_function_recommendations ⇒ Array<Types::LambdaFunctionRecommendation>
An array of objects that describe function recommendations.
-
#next_token ⇒ String
The token to use to advance to the next page of function recommendations.
Instance Attribute Details
#lambda_function_recommendations ⇒ Array<Types::LambdaFunctionRecommendation>
An array of objects that describe function recommendations.
3469 3470 3471 3472 3473 3474 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3469 class GetLambdaFunctionRecommendationsResponse < Struct.new( :next_token, :lambda_function_recommendations) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to advance to the next page of function recommendations.
This value is null when there are no more pages of function recommendations to return.
3469 3470 3471 3472 3473 3474 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3469 class GetLambdaFunctionRecommendationsResponse < Struct.new( :next_token, :lambda_function_recommendations) SENSITIVE = [] include Aws::Structure end |