Class: Aws::ComputeOptimizer::Types::GetLicenseRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The ID of the Amazon Web Services account for which to return license recommendations.

If your account is the management account of an organization, use this parameter to specify the member account for which you want to return license recommendations.

Only one account ID can be specified per request.

Returns:

  • (Array<String>)


3514
3515
3516
3517
3518
3519
3520
3521
3522
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3514

class GetLicenseRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::LicenseRecommendationFilter>

An array of objects to specify a filter that returns a more specific list of license recommendations.



3514
3515
3516
3517
3518
3519
3520
3521
3522
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3514

class GetLicenseRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of license recommendations to return with a single request.

To retrieve the remaining results, make another request with the returned ‘nextToken` value.

Returns:

  • (Integer)


3514
3515
3516
3517
3518
3519
3520
3521
3522
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3514

class GetLicenseRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to advance to the next page of license recommendations.

Returns:

  • (String)


3514
3515
3516
3517
3518
3519
3520
3521
3522
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3514

class GetLicenseRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

The ARN that identifies the Amazon EC2 instance.

The following is the format of the ARN:

‘arn:aws:ec2:region:aws_account_id:instance/instance-id`

Returns:

  • (Array<String>)


3514
3515
3516
3517
3518
3519
3520
3521
3522
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3514

class GetLicenseRecommendationsRequest < Struct.new(
  :resource_arns,
  :next_token,
  :max_results,
  :filters,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end