Class: Aws::ComputeOptimizer::Types::GetRecommendationError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes an error experienced when getting recommendations.

For example, an error is returned if you request recommendations for an unsupported Auto Scaling group, or if you request recommendations for an instance of an unsupported instance family.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


3711
3712
3713
3714
3715
3716
3717
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711

class GetRecommendationError < Struct.new(
  :identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The ID of the error.

Returns:

  • (String)


3711
3712
3713
3714
3715
3716
3717
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711

class GetRecommendationError < Struct.new(
  :identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The message, or reason, for the error.

Returns:

  • (String)


3711
3712
3713
3714
3715
3716
3717
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711

class GetRecommendationError < Struct.new(
  :identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end