Class: Aws::ComputeOptimizer::Types::GetRecommendationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRecommendationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes an error experienced when getting recommendations.
For example, an error is returned if you request recommendations for an unsupported Auto Scaling group, or if you request recommendations for an instance of an unsupported instance family.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#identifier ⇒ String
The ID of the error.
-
#message ⇒ String
The message, or reason, for the error.
Instance Attribute Details
#code ⇒ String
The error code.
3711 3712 3713 3714 3715 3716 3717 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711 class GetRecommendationError < Struct.new( :identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ID of the error.
3711 3712 3713 3714 3715 3716 3717 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711 class GetRecommendationError < Struct.new( :identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message, or reason, for the error.
3711 3712 3713 3714 3715 3716 3717 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3711 class GetRecommendationError < Struct.new( :identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |