Class: Aws::ComputeOptimizer::Types::GetRecommendationPreferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::GetRecommendationPreferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of recommendation preferences to return with a single request.
-
#next_token ⇒ String
The token to advance to the next page of recommendation preferences.
-
#resource_type ⇒ String
The target resource type of the recommendation preference for which to return preferences.
-
#scope ⇒ Types::Scope
An object that describes the scope of the recommendation preference to return.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of recommendation preferences to return with a single request.
To retrieve the remaining results, make another request with the returned ‘nextToken` value.
3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3758 class GetRecommendationPreferencesRequest < Struct.new( :resource_type, :scope, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to advance to the next page of recommendation preferences.
3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3758 class GetRecommendationPreferencesRequest < Struct.new( :resource_type, :scope, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The target resource type of the recommendation preference for which to return preferences.
The ‘Ec2Instance` option encompasses standalone instances and instances that are part of Auto Scaling groups. The `AutoScalingGroup` option encompasses only instances that are part of an Auto Scaling group.
3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3758 class GetRecommendationPreferencesRequest < Struct.new( :resource_type, :scope, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ Types::Scope
An object that describes the scope of the recommendation preference to return.
You can return recommendation preferences that are created at the organization level (for management accounts of an organization only), account level, and resource level. For more information, see
- Activating enhanced infrastructure metrics][1
-
in the *Compute
Optimizer User Guide*.
[1]: docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 3758 class GetRecommendationPreferencesRequest < Struct.new( :resource_type, :scope, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |