Class: Aws::ComputeOptimizer::Types::RDSDBInstanceRecommendationOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSDBInstanceRecommendationOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the recommendation options for a DB instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_class ⇒ String
Describes the DB instance class recommendation option for your Amazon Aurora or RDS database.
-
#performance_risk ⇒ Float
The performance risk of the DB instance recommendation option.
-
#projected_utilization_metrics ⇒ Array<Types::RDSDBUtilizationMetric>
An array of objects that describe the projected utilization metrics of the DB instance recommendation option.
-
#rank ⇒ Integer
The rank identifier of the DB instance recommendation option.
-
#savings_opportunity ⇒ Types::SavingsOpportunity
Describes the savings opportunity for recommendations of a given resource type or for the recommendation option of an individual resource.
-
#savings_opportunity_after_discounts ⇒ Types::RDSInstanceSavingsOpportunityAfterDiscounts
Describes the savings opportunity for Amazon Aurora and RDS database recommendations or for the recommendation option.
Instance Attribute Details
#db_instance_class ⇒ String
Describes the DB instance class recommendation option for your Amazon Aurora or RDS database.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |
#performance_risk ⇒ Float
The performance risk of the DB instance recommendation option.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |
#projected_utilization_metrics ⇒ Array<Types::RDSDBUtilizationMetric>
An array of objects that describe the projected utilization metrics of the DB instance recommendation option.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |
#rank ⇒ Integer
The rank identifier of the DB instance recommendation option.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |
#savings_opportunity ⇒ Types::SavingsOpportunity
Describes the savings opportunity for recommendations of a given resource type or for the recommendation option of an individual resource.
Savings opportunity represents the estimated monthly savings you can achieve by implementing a given Compute Optimizer recommendation.
Savings opportunity data requires that you opt in to Cost Explorer, as well as activate **Receive Amazon EC2 resource recommendations** in the Cost Explorer preferences page. That creates a connection between Cost Explorer and Compute Optimizer. With this connection, Cost Explorer generates savings estimates considering the price of existing resources, the price of recommended resources, and historical usage data. Estimated monthly savings reflects the projected dollar savings associated with each of the recommendations generated. For more information, see [Enabling Cost Explorer] and
- Optimizing your cost with Rightsizing Recommendations][2
-
in the
*Cost Management User Guide*.
[1]: docs.aws.amazon.com/cost-management/latest/userguide/ce-enable.html [2]: docs.aws.amazon.com/cost-management/latest/userguide/ce-rightsizing.html
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |
#savings_opportunity_after_discounts ⇒ Types::RDSInstanceSavingsOpportunityAfterDiscounts
Describes the savings opportunity for Amazon Aurora and RDS database recommendations or for the recommendation option.
Savings opportunity represents the estimated monthly savings after applying Savings Plans discounts. You can achieve this by implementing a given Compute Optimizer recommendation.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6034 class RDSDBInstanceRecommendationOption < Struct.new( :db_instance_class, :projected_utilization_metrics, :performance_risk, :rank, :savings_opportunity, :savings_opportunity_after_discounts) SENSITIVE = [] include Aws::Structure end |