Class: Aws::ComputeOptimizer::Types::RDSDBInstanceRecommendationOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizer/types.rb

Overview

Describes the recommendation options for a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_instance_classString

Describes the DB instance class recommendation option for your Amazon Aurora or RDS database.

Returns:

  • (String)


6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#performance_riskFloat

The performance risk of the DB instance recommendation option.

Returns:

  • (Float)


6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#projected_utilization_metricsArray<Types::RDSDBUtilizationMetric>

An array of objects that describe the projected utilization metrics of the DB instance recommendation option.

Returns:



6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#rankInteger

The rank identifier of the DB instance recommendation option.

Returns:

  • (Integer)


6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunityTypes::SavingsOpportunity

Describes the savings opportunity for recommendations of a given resource type or for the recommendation option of an individual resource.

Savings opportunity represents the estimated monthly savings you can achieve by implementing a given Compute Optimizer recommendation.

Savings opportunity data requires that you opt in to Cost Explorer, as well as activate **Receive Amazon EC2 resource recommendations** in the Cost Explorer preferences page. That creates a connection between Cost Explorer and Compute Optimizer. With this connection, Cost Explorer generates savings estimates considering the price of existing resources, the price of recommended resources, and historical usage data. Estimated monthly savings reflects the projected dollar savings associated with each of the recommendations generated. For more information, see [Enabling Cost Explorer] and

Optimizing your cost with Rightsizing Recommendations][2

in the

*Cost Management User Guide*.

[1]: docs.aws.amazon.com/cost-management/latest/userguide/ce-enable.html [2]: docs.aws.amazon.com/cost-management/latest/userguide/ce-rightsizing.html



6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end

#savings_opportunity_after_discountsTypes::RDSInstanceSavingsOpportunityAfterDiscounts

Describes the savings opportunity for Amazon Aurora and RDS database recommendations or for the recommendation option.

Savings opportunity represents the estimated monthly savings after applying Savings Plans discounts. You can achieve this by implementing a given Compute Optimizer recommendation.



6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6010

class RDSDBInstanceRecommendationOption < Struct.new(
  :db_instance_class,
  :projected_utilization_metrics,
  :performance_risk,
  :rank,
  :savings_opportunity,
  :savings_opportunity_after_discounts)
  SENSITIVE = []
  include Aws::Structure
end