Class: Aws::ComputeOptimizer::Types::RDSDBRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSDBRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes an Amazon Aurora and RDS database recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the Amazon Aurora or RDS database.
-
#current_db_instance_class ⇒ String
The DB instance class of the current Aurora or RDS DB instance.
-
#current_instance_performance_risk ⇒ String
The performance risk for the current DB instance.
-
#current_storage_configuration ⇒ Types::DBStorageConfiguration
The configuration of the current DB storage.
-
#current_storage_estimated_monthly_volume_io_ps_cost_variation ⇒ String
The level of variation in monthly I/O costs for the current DB storage configuration.
-
#db_cluster_identifier ⇒ String
The identifier for DB cluster.
-
#effective_recommendation_preferences ⇒ Types::RDSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for DB instances.
-
#engine ⇒ String
The engine of the DB instance.
-
#engine_version ⇒ String
The database engine version.
-
#idle ⇒ String
This indicates if the DB instance is idle or not.
-
#instance_finding ⇒ String
The finding classification of an Amazon Aurora and RDS DB instance.
-
#instance_finding_reason_codes ⇒ Array<String>
The reason for the finding classification of a DB instance.
-
#instance_recommendation_options ⇒ Array<Types::RDSDBInstanceRecommendationOption>
An array of objects that describe the recommendation options for the RDS DB instance.
-
#last_refresh_timestamp ⇒ Time
The timestamp of when the DB instance recommendation was last generated.
-
#lookback_period_in_days ⇒ Float
The number of days the DB instance utilization metrics were analyzed.
-
#promotion_tier ⇒ Integer
The promotion tier for the Aurora instance.
-
#resource_arn ⇒ String
The ARN of the current Amazon Aurora or RDS database.
-
#storage_finding ⇒ String
The finding classification of Amazon RDS DB instance storage.
-
#storage_finding_reason_codes ⇒ Array<String>
The reason for the finding classification of RDS DB instance storage.
-
#storage_recommendation_options ⇒ Array<Types::RDSDBStorageRecommendationOption>
An array of objects that describe the recommendation options for DB instance storage.
-
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your DB instance recommendations.
-
#utilization_metrics ⇒ Array<Types::RDSDBUtilizationMetric>
An array of objects that describe the utilization metrics of the DB instance.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the Amazon Aurora or RDS database.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#current_db_instance_class ⇒ String
The DB instance class of the current Aurora or RDS DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#current_instance_performance_risk ⇒ String
The performance risk for the current DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#current_storage_configuration ⇒ Types::DBStorageConfiguration
The configuration of the current DB storage.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#current_storage_estimated_monthly_volume_io_ps_cost_variation ⇒ String
The level of variation in monthly I/O costs for the current DB storage configuration.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The identifier for DB cluster.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#effective_recommendation_preferences ⇒ Types::RDSEffectiveRecommendationPreferences
Describes the effective recommendation preferences for DB instances.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The engine of the DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The database engine version.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#idle ⇒ String
This indicates if the DB instance is idle or not.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_finding ⇒ String
The finding classification of an Amazon Aurora and RDS DB instance.
For more information about finding classifications, see [ Finding classifications for Aurora and RDS databases] in the *Compute Optimizer User Guide*.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_finding_reason_codes ⇒ Array<String>
The reason for the finding classification of a DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_recommendation_options ⇒ Array<Types::RDSDBInstanceRecommendationOption>
An array of objects that describe the recommendation options for the RDS DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#last_refresh_timestamp ⇒ Time
The timestamp of when the DB instance recommendation was last generated.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#lookback_period_in_days ⇒ Float
The number of days the DB instance utilization metrics were analyzed.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#promotion_tier ⇒ Integer
The promotion tier for the Aurora instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the current Amazon Aurora or RDS database.
The following is the format of the ARN:
‘arn:aws:rds:region:accountId:db:resourceName`
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#storage_finding ⇒ String
The finding classification of Amazon RDS DB instance storage.
For more information about finding classifications, see [ Finding classifications for Aurora and RDS databases] in the *Compute Optimizer User Guide*.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#storage_finding_reason_codes ⇒ Array<String>
The reason for the finding classification of RDS DB instance storage.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#storage_recommendation_options ⇒ Array<Types::RDSDBStorageRecommendationOption>
An array of objects that describe the recommendation options for DB instance storage.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags assigned to your DB instance recommendations.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#utilization_metrics ⇒ Array<Types::RDSDBUtilizationMetric>
An array of objects that describe the utilization metrics of the DB instance.
6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6141 class RDSDBRecommendation < Struct.new( :resource_arn, :account_id, :engine, :engine_version, :promotion_tier, :current_db_instance_class, :current_storage_configuration, :db_cluster_identifier, :idle, :instance_finding, :storage_finding, :instance_finding_reason_codes, :current_instance_performance_risk, :current_storage_estimated_monthly_volume_io_ps_cost_variation, :storage_finding_reason_codes, :instance_recommendation_options, :storage_recommendation_options, :utilization_metrics, :effective_recommendation_preferences, :lookback_period_in_days, :last_refresh_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |