Class: Aws::ComputeOptimizer::Types::RDSDatabaseProjectedMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSDatabaseProjectedMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the projected metrics of an Amazon Aurora and RDS database recommendation option.
To determine the performance difference between your current Amazon Aurora and RDS database and the recommended option, compare the metric data of your service against its projected metric data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the projected metric.
-
#timestamps ⇒ Array<Time>
The timestamps of the projected metric.
-
#values ⇒ Array<Float>
The values for the projected metric.
Instance Attribute Details
#name ⇒ String
The name of the projected metric.
6337 6338 6339 6340 6341 6342 6343 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6337 class RDSDatabaseProjectedMetric < Struct.new( :name, :timestamps, :values) SENSITIVE = [] include Aws::Structure end |
#timestamps ⇒ Array<Time>
The timestamps of the projected metric.
6337 6338 6339 6340 6341 6342 6343 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6337 class RDSDatabaseProjectedMetric < Struct.new( :name, :timestamps, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<Float>
The values for the projected metric.
6337 6338 6339 6340 6341 6342 6343 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6337 class RDSDatabaseProjectedMetric < Struct.new( :name, :timestamps, :values) SENSITIVE = [] include Aws::Structure end |