Class: Aws::ComputeOptimizer::Types::RDSDatabaseRecommendedOptionProjectedMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizer::Types::RDSDatabaseRecommendedOptionProjectedMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizer/types.rb
Overview
Describes the projected metrics of an Amazon Aurora and RDS database recommendation option.
To determine the performance difference between your current Amazon Aurora and RDS database and the recommended option, compare the metric data of your service against its projected metric data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#projected_metrics ⇒ Array<Types::RDSDatabaseProjectedMetric>
An array of objects that describe the projected metric.
-
#rank ⇒ Integer
The rank identifier of the Amazon Aurora or RDS DB instance recommendation option.
-
#recommended_db_instance_class ⇒ String
The recommended DB instance class for the Amazon Aurora or RDS database.
Instance Attribute Details
#projected_metrics ⇒ Array<Types::RDSDatabaseProjectedMetric>
An array of objects that describe the projected metric.
6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6368 class RDSDatabaseRecommendedOptionProjectedMetric < Struct.new( :recommended_db_instance_class, :rank, :projected_metrics) SENSITIVE = [] include Aws::Structure end |
#rank ⇒ Integer
The rank identifier of the Amazon Aurora or RDS DB instance recommendation option.
6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6368 class RDSDatabaseRecommendedOptionProjectedMetric < Struct.new( :recommended_db_instance_class, :rank, :projected_metrics) SENSITIVE = [] include Aws::Structure end |
#recommended_db_instance_class ⇒ String
The recommended DB instance class for the Amazon Aurora or RDS database.
6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-computeoptimizer/types.rb', line 6368 class RDSDatabaseRecommendedOptionProjectedMetric < Struct.new( :recommended_db_instance_class, :rank, :projected_metrics) SENSITIVE = [] include Aws::Structure end |